%define opensc_module "OpenSC PKCS #11 Module"
%define nssdb %{_sysconfdir}/pki/nssdb

Summary:        Smart card library and applications
Name:           opensc
Version:        0.25.0
Release:        1%{?dist}

License:        LGPLv2+
URL:            https://github.com/OpenSC/OpenSC/wiki
Source0:        https://github.com/OpenSC/OpenSC/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        opensc.module

BuildRequires:  make autoconf automake libtool gcc
BuildRequires:  pcsc-lite-devel readline-devel openssl-devel
BuildRequires:  /usr/bin/xsltproc docbook-style-xsl zlib-devel
BuildRequires:  libcmocka-devel openssl bash-completion

Requires:       pcsc-lite-libs
Requires:       pcsc-lite

Provides:       bundled(simclist) = 1.5

%description
OpenSC provides a set of libraries and utilities to work with smart cards. Its
main focus is on cards that support cryptographic operations, and facilitate
their use in security applications such as authentication, mail encryption and
digital signatures. OpenSC implements the PKCS#11 API so applications
supporting this API (such as Mozilla Firefox and Thunderbird) can use it. On
the card OpenSC implements the PKCS#15 standard and aims to be compatible with
every software/card that does so, too.


%prep
%autosetup -p1

sed -i -e '/XFAIL_TESTS/,$ {
  s/XFAIL_TESTS.*/XFAIL_TESTS=test-pkcs11-tool-test-threads.sh/
  q
}' tests/Makefile.am


cp -p src/pkcs15init/README ./README.pkcs15init
cp -p src/scconf/README.scconf .
sed -i -e 's|/usr/local/towitoko/lib/|/usr/lib/ctapi/|' etc/opensc.conf.example.in


%build
autoreconf -fvi

sed -i -e 's|"/lib /usr/lib\b|"/%{_lib} %{_libdir}|' configure # lib64 rpaths
CFLAGS="$CFLAGS -Wstrict-aliasing=2 -Wno-deprecated-declarations"

%configure  --disable-static \
  --disable-autostart-items \
  --disable-notify \
  --disable-assert \
  --enable-pcsc \
  --enable-cmocka \
  --enable-sm \
  %{nil}
%make_build


%check
make check


%install
%make_install
install -D -pm644 %{SOURCE1} %{buildroot}%{_datadir}/p11-kit/modules/opensc.module

ln -s %{_sysconfdir}/opensc.conf %{buildroot}%{_sysconfdir}/opensc-%{_arch}.conf

find %{buildroot}%{_libdir} -type f -name "*.la" | xargs rm

rm -rf %{buildroot}%{_datadir}/doc/opensc

rm -f %{buildroot}%{_libdir}/libopensc.so
rm -f %{buildroot}%{_libdir}/pkgconfig/*.pc
rm -f %{buildroot}%{_libdir}/libsmm-local.so
rm -rf %{buildroot}%{_datadir}/bash-completion/

rm -rf %{buildroot}%{_bindir}/npa-tool
rm -rf %{buildroot}%{_mandir}/man1/npa-tool.1*
rm -rf %{buildroot}%{_bindir}/pkcs11-register
rm -rf %{buildroot}%{_mandir}/man1/pkcs11-register.1*
rm %{buildroot}%{_datadir}/applications/org.opensc.notify.desktop
rm %{buildroot}%{_mandir}/man1/opensc-notify.1*


%files
%license COPYING
%doc NEWS README*
%{_bindir}/cardos-tool
%{_bindir}/cryptoflex-tool
%{_bindir}/eidenv
%{_bindir}/iasecc-tool
%{_bindir}/gids-tool
%{_bindir}/netkey-tool
%{_bindir}/openpgp-tool
%{_bindir}/opensc-explorer
%{_bindir}/opensc-tool
%{_bindir}/opensc-asn1
%{_bindir}/piv-tool
%{_bindir}/pkcs11-tool
%{_bindir}/pkcs15-crypt
%{_bindir}/pkcs15-init
%{_bindir}/pkcs15-tool
%{_bindir}/sc-hsm-tool
%{_bindir}/dnie-tool
%{_bindir}/westcos-tool
%{_bindir}/egk-tool
%{_bindir}/goid-tool
%{_bindir}/dtrust-tool
%{_libdir}/lib*.so.*
%{_libdir}/opensc-pkcs11.so
%{_libdir}/pkcs11-spy.so
%{_libdir}/onepin-opensc-pkcs11.so
%{_libdir}/pkcs11/opensc-pkcs11.so
%{_libdir}/pkcs11/onepin-opensc-pkcs11.so
%{_libdir}/pkcs11/pkcs11-spy.so
%{_datadir}/opensc/
%{_datadir}/p11-kit/modules/opensc.module
%config(noreplace) %{_sysconfdir}/opensc.conf
%config(noreplace) %{_sysconfdir}/opensc-%{_arch}.conf
%dir %{_datadir}/p11-kit
%dir %{_datadir}/p11-kit/modules
%{_mandir}/man1/cardos-tool.1*
%{_mandir}/man1/cryptoflex-tool.1*
%{_mandir}/man1/eidenv.1*
%{_mandir}/man1/gids-tool.1*
%{_mandir}/man1/goid-tool.1*
%{_mandir}/man1/iasecc-tool.1*
%{_mandir}/man1/netkey-tool.1*
%{_mandir}/man1/openpgp-tool.1*
%{_mandir}/man1/opensc-explorer.*
%{_mandir}/man1/opensc-tool.1*
%{_mandir}/man1/opensc-asn1.1*
%{_mandir}/man1/piv-tool.1*
%{_mandir}/man1/pkcs11-tool.1*
%{_mandir}/man1/pkcs15-crypt.1*
%{_mandir}/man1/pkcs15-init.1*
%{_mandir}/man1/pkcs15-tool.1*
%{_mandir}/man1/sc-hsm-tool.1*
%{_mandir}/man1/westcos-tool.1*
%{_mandir}/man1/dnie-tool.1*
%{_mandir}/man1/egk-tool.1*
%{_mandir}/man1/dtrust-tool.1*
%{_mandir}/man5/pkcs15-profile.5*
%{_mandir}/man5/opensc.conf.5*


%changelog
* Thu Mar 7 2024 Anakin Zhang <anakinzhang@tencent.com> - 0.25.0-1
- Upgrade to 0.25.0

* Fri Nov 10 2023 Anakin Zhang <anakinzhang@tencent.com> - 0.23.0-4
- Fix CVE-2023-2977

* Thu Nov 9 2023 Anakin Zhang <anakinzhang@tencent.com> - 0.23.0-3
- Fix CVE-2023-40660 and CVE-2023-4535

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.23.0-2
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Jul 12 2023 Shuo Wang <abushwang@tencent.com> - 0.23.0-1
- update to 0.23.0

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.22.0-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.22.0-2
- Rebuilt for OpenCloudOS Stream 23

* Thu Feb 16 2023 cunshunxia <cunshunxia@tencent.com> - 0.22.0-1
- initial build
